aboutsummaryrefslogtreecommitdiff
path: root/pyAggr3g470r.py
diff options
context:
space:
mode:
authorcedricbonhomme <devnull@localhost>2012-03-10 08:57:21 +0100
committercedricbonhomme <devnull@localhost>2012-03-10 08:57:21 +0100
commit2d945e8f301c45776c5b8efeb0b4ed5da68009c7 (patch)
treeae04c9a1a4d853ca913cfa18a01db5b597ddfa7f /pyAggr3g470r.py
parentWe can now again delete a feed from the management page. (diff)
downloadnewspipe-2d945e8f301c45776c5b8efeb0b4ed5da68009c7.tar.gz
newspipe-2d945e8f301c45776c5b8efeb0b4ed5da68009c7.tar.bz2
newspipe-2d945e8f301c45776c5b8efeb0b4ed5da68009c7.zip
Updated comments.
Diffstat (limited to 'pyAggr3g470r.py')
-rwxr-xr-xpyAggr3g470r.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/pyAggr3g470r.py b/pyAggr3g470r.py
index a9745bac..7c605821 100755
--- a/pyAggr3g470r.py
+++ b/pyAggr3g470r.py
@@ -241,7 +241,7 @@ class Root:
def management(self, max_nb_articles=5):
"""
Management page.
Allows adding and deleting feeds. Export functions of the SQLite data base
and display some statistics.
"""
feeds = self.mongo.get_all_collections()
@@ -963,7 +963,7 @@ class Root:
def mark_as_read(self, target=""):
"""
Mark one (or more) article(s) as read by setting the value of the field
- 'article_readed' of the SQLite database to 1.
+ 'article_readed' of the MongoDB database to 'True'.
"""
param, _, identifiant = target.partition(':')
@@ -1103,7 +1103,7 @@ class Root:
def remove_feed(self, feed_id):
"""
Remove a feed from the file feed.lst and from the SQLite base.
"""
html = htmlheader()
html += htmlnav
@@ -1209,7 +1209,7 @@ class Root:
def export(self, export_method):
"""
Export articles currently loaded from the SQLite database with
the appropriate function of the 'export' module.
"""
try:
@@ -241,7 +241,7 @@ class Root:
"""
Management page.
- Allows adding and deleting feeds. Export functions of the SQLite data base
+ Allows adding and deleting feeds. Export functions of the MongoDB data base
and display some statistics.
"""
@@ -1103,7 +1103,7 @@ class Root:
def remove_feed(self, feed_id):
"""
- Remove a feed from the file feed.lst and from the SQLite base.
+ Remove a feed from the file feed.lst and from the MongoDB database.
"""
html = htmlheader()
@@ -1209,7 +1209,7 @@ class Root:
def export(self, export_method):
"""
- Export articles currently loaded from the SQLite database with
+ Export articles currently loaded from the MongoDB database with
the appropriate function of the 'export' module.
"""
bgstack15